@@ -1,12 +1,9 @@
 from typing import Any, Dict, List, NewType, Optional, TYPE_CHECKING
-
+from zuper_typing import dataclass
 
 if TYPE_CHECKING:
     from dataclasses import dataclass
-else:
-    from zuper_typing import dataclass
 
-import numpy as np
 
 from .basics import InteractionProtocol
 from .protocol_agent import EpisodeStart
@@ -41,8 +38,12 @@ __all__ = [
     "PROTOCOL_FULL",
     "PROTOCOL_LEARNING",
     "PROTOCOL_NORMAL",
+    "PROTOCOL_STATE",
     "Termination",
     "ProtocolDesc",
+    "FriendlyVelocity",
+    "JPGImageWithTimestamp",
+    "FriendlyPose",
 ]
 
 RobotName = str
@@ -51,23 +52,42 @@ RobotName = str
 @dataclass
 class JPGImage:
     """
-        An image in JPG format.
+    An image in JPG format.
 
-        jpg_data: Bytes of a JPG file
+    jpg_data: Bytes of a JPG file
     """
 
     jpg_data: bytes
 
 
+@dataclass
+class JPGImageWithTimestamp(JPGImage):
+    timestamp: float
+
+
 @dataclass
 class SetMap:
     map_data: Any
 
 
+@dataclass
+class FriendlyPose:
+    x: float
+    y: float
+    theta_deg: float
+
+
+@dataclass
+class FriendlyVelocity:
+    x: float
+    y: float
+    theta_deg: float
+
+
 @dataclass
 class RobotConfiguration:
-    pose: np.ndarray
-    velocity: np.ndarray
+    pose: FriendlyPose
+    velocity: FriendlyVelocity
 
 
 @dataclass
@@ -126,11 +146,11 @@ class Termination:
 @dataclass
 class SimulationState:
     """
-        Returns the simulation state.
+    Returns the simulation state.
 
-        done: Whether the simulation should be terminated.
-        done_why: Human-readable short message.
-        done_code: Short string to use as code for statistics.
+    done: Whether the simulation should be terminated.
+    done_why: Human-readable short message.
+    done_code: Short string to use as code for statistics.
     """
 
     done: bool
@@ -153,12 +173,12 @@ class Metric:
 @dataclass
 class PerformanceMetrics:
     """
-        Performance metrics for an agent.
+    Performance metrics for an agent.
 
-        By convention there will be one called "reward" for RL tasks.
+    By convention there will be one called "reward" for RL tasks.
 
-        Note that the values are *cumulative* to make it possible to have
-        a sampling-invariant behavior.
+    Note that the values are *cumulative* to make it possible to have
+    a sampling-invariant behavior.
     """
 
     metrics: Dict[str, Metric]
@@ -190,7 +210,7 @@ class DumpState:
 
 @dataclass
 class StateDump:
-    """ Opaque object that contains the simulator's state, whichever it is. """
+    """Opaque object that contains the simulator's state, whichever it is."""
 
     state: object
 
@@ -201,7 +221,10 @@ PROTOCOL_NORMAL = ProtocolDesc("PROTOCOL_NORMAL")
 """ only the things that are visible """
 
 PROTOCOL_FULL = ProtocolDesc("PROTOCOL_FULL")
-""" Full state observation"""
+""" Full state observation AND camera """
+
+PROTOCOL_STATE = ProtocolDesc("PROTOCOL_STATE")
+""" Only state observation, without camera """
 
 PROTOCOL_LEARNING = ProtocolDesc("PROTOCOL_LEARNING")
 """ Also includes a feedback signal"""
@@ -229,7 +252,7 @@ class ScenarioRobotSpec:
 @dataclass
 class ScenarioDuckieSpec:
     color: str  # css color
-    pose: np.ndarray  # SE2
+    pose: FriendlyPose  # SE2
 
 
 @dataclass
@@ -238,8 +261,9 @@ class Scenario:
     scenario_name: str
     environment: Any
     player_robots: List[RobotName]
-    robots: Dict[str, ScenarioRobotSpec]
+    robots: Dict[RobotName, ScenarioRobotSpec]
     duckies: Dict[str, ScenarioDuckieSpec]
+    payload_yaml: str
 
 
 @dataclass
@@ -252,13 +276,14 @@ class SpawnRobot:
     configuration: RobotConfiguration
     color: str = "red"
     # motion: Optional[NPMotion]
+    simulate_camera: bool = True
 
 
 @dataclass
 class SpawnDuckie:
     name: str
     color: str
-    pose: np.ndarray
+    pose: FriendlyPose
 
 
 description = """\
